DO NOT REPLY [Bug 10768] New: - 'AddHandler cgi-script cgi' does not specifically find cgi file extension

2002-07-13 Thread bugzilla
DO NOT REPLY TO THIS EMAIL, BUT PLEASE POST YOUR BUG 
RELATED COMMENTS THROUGH THE WEB INTERFACE AVAILABLE AT
http://nagoya.apache.org/bugzilla/show_bug.cgi?id=10768.
ANY REPLY MADE TO THIS MESSAGE WILL NOT BE COLLECTED AND 
INSERTED IN THE BUG DATABASE.

http://nagoya.apache.org/bugzilla/show_bug.cgi?id=10768

'AddHandler cgi-script cgi' does not specifically find cgi file extension 

   Summary: 'AddHandler cgi-script cgi' does not specifically find
cgi file extension
   Product: Apache httpd-2.0
   Version: 2.0.39
  Platform: PC
   URL: http://nagoya.apache.org
OS/Version: Linux
Status: NEW
  Severity: Minor
  Priority: Other
 Component: mod_mime
AssignedTo: bugs@httpd.apache.org
ReportedBy: [EMAIL PROTECTED]


When the directive AddHandler cgi-script cgi is used, and presumably similar 
constructions, matches will be made on filenames containing .cgi and not just 
files with the extension .cgi (or .pl, or other).

This was discovered when a CGI program was compiled from source named 
compiled.cgi.c and the executable output was compiled.cgi.  When both are 
visible on an index page delivered from Apache, clicking on compiled.cgi.c 
should cause it to deliver a plain text document.  Instead, Apache attempts to 
run it as a cgi program.

The compilation itself runs as expected because Apache properly delivers 
compiled.cgi to the handler.

Somewhere (mod_mime ?) an improper match is made on file extensions.  I 
couldn't 
find it myself.

-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



DO NOT REPLY [Bug 10772] New: - [PATCH] RequestHeader directive for mod_headers.c

2002-07-13 Thread bugzilla
DO NOT REPLY TO THIS EMAIL, BUT PLEASE POST YOUR BUG 
RELATED COMMENTS THROUGH THE WEB INTERFACE AVAILABLE AT
http://nagoya.apache.org/bugzilla/show_bug.cgi?id=10772.
ANY REPLY MADE TO THIS MESSAGE WILL NOT BE COLLECTED AND 
INSERTED IN THE BUG DATABASE.

http://nagoya.apache.org/bugzilla/show_bug.cgi?id=10772

[PATCH] RequestHeader directive for mod_headers.c

   Summary: [PATCH] RequestHeader directive for mod_headers.c
   Product: Apache httpd-1.3
   Version: 1.3.26
  Platform: All
OS/Version: All
Status: NEW
  Severity: Enhancement
  Priority: Other
 Component: mod_headers
AssignedTo: bugs@httpd.apache.org
ReportedBy: [EMAIL PROTECTED]


Recently in a more complicated HA setup involving apache 1.3.xx we needed to be
able to set additional headers in the request. This doesn't seem to be possible
in 1.3.26.

This patch adds a directive RequestHeader to mod_headers.c. The syntax is
exactly as for Header.


--- mod_headers.c-2002-07-13Wed Mar 13 21:05:33 2002
+++ mod_headers.c   Sat Jul 13 12:57:38 2002
@@ -59,13 +59,19 @@
 /*
  * mod_headers.c: Add/append/remove HTTP response headers
  * Written by Paul Sutton, [EMAIL PROTECTED], 1 Oct 1996
+ * Updated with RequestHeader by Martin Algesten,
+ *   [EMAIL PROTECTED], 13 Jul 2002.
  *
  * New directive, Header, can be used to add/replace/remove HTTP headers.
  * Valid in both per-server and per-dir configurations.
+ * In addition directive, RequestHeader, can be used exactly as Header but
+ * with the difference that the header is added to the request headers rather
+ * than the response.
  *
  * Syntax is:
  *
  *   Header action header value
  *
  * Where action is one of:
  * set- set this header, replacing any old value
@@ -77,7 +83,7 @@
  * Where action is unset, the third argument (value) should not be given.
  * The header name can include the colon, or not.
  *
- * The Header directive can only be used where allowed by the FileInfo 
+ * The directives can only be used where allowed by the FileInfo 
  * override.
  *
  * When the request is processed, the header directives are processed in
@@ -112,7 +118,15 @@
 hdr_unset = 'u' /* unset header */
 } hdr_actions;
 
+
+typedef enum {
+  hdrs_in  = 'i',   /* Add header to incoming (request) headers */
+  hdrs_out = 'o'/* Add header to outgoing (response) headers */
+} hdrs_inout;
+
+
 typedef struct {
+hdrs_inout inout;
 hdr_actions action;
 char *header;
 char *value;
@@ -154,7 +168,7 @@
 }
 
 
-static const char *header_cmd(cmd_parms *cmd, headers_conf * dirconf, char
*action, char *hdr, char *value)
+static const char *header_cmd(cmd_parms *cmd, headers_conf * dirconf, char
*action, char *hdr, char *value, hdrs_inout inout )
 {
 header_entry *new;
 server_rec *s = cmd-server;
@@ -169,6 +183,8 @@
 new = (header_entry *) ap_push_array(serverconf-headers);
 }
 
+new-inout = inout;
+
 if (!strcasecmp(action, set))
 new-action = hdr_set;
 else if (!strcasecmp(action, add))
@@ -196,33 +212,56 @@
 return NULL;
 }
 
+static const char *outheader_cmd(cmd_parms *cmd, headers_conf * dirconf, char
*action, char *hdr, char *value) {
+  
+  header_cmd( cmd, dirconf, action, hdr, value, hdrs_out );
+
+}
+
+static const char *inheader_cmd(cmd_parms *cmd, headers_conf * dirconf, char
*action, char *hdr, char *value) {
+
+  header_cmd( cmd, dirconf, action, hdr, value, hdrs_in );
+
+}
+
 static const command_rec headers_cmds[] =
 {
-{Header, header_cmd, NULL, OR_FILEINFO, TAKE23,
+{Header, outheader_cmd, NULL, OR_FILEINFO, TAKE23,
+ an action, header and value},
+{RequestHeader, inheader_cmd, NULL, OR_FILEINFO, TAKE23,
  an action, header and value},
 {NULL}
 };
 
 static void do_headers_fixup(request_rec *r, array_header *headers)
 {
-int i;
+  int i; table *t;
 
 for (i = 0; i  headers-nelts; ++i) {
 header_entry *hdr = ((header_entry *) (headers-elts))[i];
-switch (hdr-action) {
-case hdr_add:
-ap_table_addn(r-headers_out, hdr-header, hdr-value);
-break;
-case hdr_append:
-ap_table_mergen(r-headers_out, hdr-header, hdr-value);
-break;
-case hdr_set:
-ap_table_setn(r-headers_out, hdr-header, hdr-value);
-break;
-case hdr_unset:
-ap_table_unset(r-headers_out, hdr-header);
-break;
-}
+   switch (hdr-inout) {
+   case hdrs_out:
+ t = r-headers_out;
+ break;
+   case hdrs_in:
+ t = r-headers_in;
+ break;
+   }
+   switch (hdr-action) {
+   case hdr_add:
+ ap_table_addn(t, hdr-header, hdr-value);
+ break;
+   case hdr_append:
+ ap_table_mergen(t, hdr-header, 

DO NOT REPLY [Bug 10773] New: - Acccess warning is not informative when trying to run cgi

2002-07-13 Thread bugzilla
DO NOT REPLY TO THIS EMAIL, BUT PLEASE POST YOUR BUG 
RELATED COMMENTS THROUGH THE WEB INTERFACE AVAILABLE AT
http://nagoya.apache.org/bugzilla/show_bug.cgi?id=10773.
ANY REPLY MADE TO THIS MESSAGE WILL NOT BE COLLECTED AND 
INSERTED IN THE BUG DATABASE.

http://nagoya.apache.org/bugzilla/show_bug.cgi?id=10773

Acccess warning is not informative when trying to run cgi

   Summary: Acccess warning is not informative when trying to run
cgi
   Product: Apache httpd-2.0
   Version: 2.0.36
  Platform: All
OS/Version: All
Status: NEW
  Severity: Minor
  Priority: Other
 Component: All
AssignedTo: bugs@httpd.apache.org
ReportedBy: [EMAIL PROTECTED]
CC: [EMAIL PROTECTED]


the permissions of this cgi are such that there is an access violation. It was
777, and I was getting:
---
Server error!
Error message:
Premature end of script headers: t.cgi

If you think this is a server error, please contact the webmaster
Error 500
Apache/2.0.36 (Unix) PHP/4.2.1
---

a different error message would be more useful.

-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



DO NOT REPLY [Bug 10774] New: - apr_shm_create core dump

2002-07-13 Thread bugzilla
DO NOT REPLY TO THIS EMAIL, BUT PLEASE POST YOUR BUG 
RELATED COMMENTS THROUGH THE WEB INTERFACE AVAILABLE AT
http://nagoya.apache.org/bugzilla/show_bug.cgi?id=10774.
ANY REPLY MADE TO THIS MESSAGE WILL NOT BE COLLECTED AND 
INSERTED IN THE BUG DATABASE.

http://nagoya.apache.org/bugzilla/show_bug.cgi?id=10774

apr_shm_create core dump

   Summary: apr_shm_create core dump
   Product: Apache httpd-2.0
   Version: 2.0.39
  Platform: PC
OS/Version: Linux
Status: NEW
  Severity: Critical
  Priority: Other
 Component: Core
AssignedTo: bugs@httpd.apache.org
ReportedBy: [EMAIL PROTECTED]


I get a core dump when trying to run apache, no matter what the configuration or
threading type.

#0  0x40079361 in apr_shm_create (m=0x3d306c5a, reqsize=0, 
filename=0x2634 Address 0x2634 out of bounds, pool=0x2634) at shm.c:410
410 *m = new_m;

This is Linux 2.2.19pre13ext3 SMP, running on a dual cpu machine.
all modules enabled, shared=max.

-
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]



DO NOT REPLY [Bug 10781] New: - Can not see the pdf files on my server on the forms page.

2002-07-13 Thread bugzilla
DO NOT REPLY TO THIS EMAIL, BUT PLEASE POST YOUR BUG 
RELATED COMMENTS THROUGH THE WEB INTERFACE AVAILABLE AT
http://nagoya.apache.org/bugzilla/show_bug.cgi?id=10781.
ANY REPLY MADE TO THIS MESSAGE WILL NOT BE COLLECTED AND 
INSERTED IN THE BUG DATABASE.

http://nagoya.apache.org/bugzilla/show_bug.cgi?id=10781

Can not see the pdf files on my server on the forms page.

   Summary: Can not see the pdf files on my server on the forms
page.
   Product: Apache httpd-2.0
   Version: 2.0.39
  Platform: Alpha
   URL: http://www.orwacog.org
OS/Version: Windows NT/2K
Status: NEW
  Severity: Normal
  Priority: Other
 Component: All
AssignedTo: bugs@httpd.apache.org
ReportedBy: [EMAIL PROTECTED]


I was using Apache 2.0.39 with virtual hosts.  It was fresh load of NT with 
service pack 6a and this apache and Cerberus FTP server. This page has worked 
in the past with 2.0.36.  The pdf files come up as a blank page.  Tried 
everything thinking that it was not the Apache doing it.  Then unistalled 
2.0.39 and installed 1.3.26 and it worked under windows.  But when the 2.0.39 
was running and I went into Mandrake 8.1 then it would only download to my home 
file.  In windows I was using IE 6.0.  My server is a PII 233 with Intel 815EEA 
board hooked to a cable modem.  My phone number is 541-882-7653 or 541-891-8998
(cell phone).  The other web pages run fine except for this little clich.

-
@@ -59,13 +59,19 @@
  * Syntax is:
  *
- *   Header action header value
+ *   Headeraction header value
+ *   RequestHeader action header value
  *
  * Where action is one of:
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]